@@ -7,6 +7,11 @@
 G_BEGIN_DECLS
 
 
+#include "gtksourceiter.h"
+
+#define GTK_TYPE_SOURCE_SEARCH_FLAGS gtk_source_search_flags_get_type()
+GType gtk_source_search_flags_get_type (void);
+
 #include "gtksourcetagstyle.h"
 
 #define GTK_TYPE_SOURCE_TAG_STYLE_MASK gtk_source_tag_style_mask_get_type()
